@@ -20,6 +20,7 @@ from botocore.client import BaseClient, ClientMeta
 from .type_defs import (
     BatchGetRecordIdentifierTypeDef,
     BatchGetRecordResponseTypeDef,
+    EmptyResponseMetadataTypeDef,
     FeatureValueTypeDef,
     GetRecordResponseTypeDef,
 )
@@ -62,7 +63,7 @@ class SageMakerFeatureStoreRuntimeClient(BaseClient):
         """
 
     def batch_get_record(
-        self, *, Identifiers: Sequence["BatchGetRecordIdentifierTypeDef"]
+        self, *, Identifiers: Sequence[BatchGetRecordIdentifierTypeDef]
     ) -> BatchGetRecordResponseTypeDef:
         """
         Retrieves a batch of `Records` from a `FeatureGroup` .
@@ -81,7 +82,7 @@ class SageMakerFeatureStoreRuntimeClient(BaseClient):
 
     def delete_record(
         self, *, FeatureGroupName: str, RecordIdentifierValueAsString: str, EventTime: str
-    ) -> None:
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Deletes a `Record` from a `FeatureGroup`.
 
@@ -117,7 +118,9 @@ class SageMakerFeatureStoreRuntimeClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_featurestore_runtime/client/#get_record)
         """
 
-    def put_record(self, *, FeatureGroupName: str, Record: Sequence["FeatureValueTypeDef"]) -> None:
+    def put_record(
+        self, *, FeatureGroupName: str, Record: Sequence[FeatureValueTypeDef]
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Used for data ingestion into the `FeatureStore`.
 
